@@ -99,6 +99,17 @@ class Locale(object):
             'xkblayout': 'de',
             'language': 'de',
         }),
+        ('el_GR', {
+            'name': 'Ελληνικά (Ελλάδα)',
+            'layoutname': 'Greek',
+            'locale': 'el_GR.utf8',
+            'keymap': 'gr',
+            'timezone': 'Europe/Athens',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'gr',
+            'language': 'gr',
+        }),
         ('en_AU', {
             'name': 'English (Australia)',
             'layoutname': 'English',
